@@ -508,7 +508,7 @@ class FormatDecisionState(object):
     if is_multiline_string:
       # This is a multiline string. Only look at the first line.
       self.column += len(current.value.split('\n')[0])
-    elif not current.is_pseudo_paren or current.value == '(':
+    elif not current.is_pseudo_paren:
       self.column += len(current.value)
 
     self.next_token = self.next_token.next_token
@@ -528,14 +528,17 @@ class FormatDecisionState(object):
 
   def _FitsOnLine(self, start, end):
     """Determines if line between start and end can fit on the current line."""
-    length = end.total_length - start.total_length + len(start.value)
-    return length + self.column < self.column_limit
+    length = end.total_length - start.total_length
+    if not start.is_pseudo_paren:
+      length += len(start.value)
+    return length + self.column <= self.column_limit
 
   def _EachDictEntryFitsOnOneLine(self, opening):
     """Determine if each dict elems can fit on one line."""
     closing = opening.matching_bracket
     entry_start = opening.next_token
     current = opening.next_token.next_token
+
     while current and current != closing:
       if format_token.Subtype.DICTIONARY_KEY in current.subtypes:
         length = current.previous_token.total_length - entry_start.total_length
@@ -544,12 +547,31 @@ class FormatDecisionState(object):
           return False
         entry_start = current
       if current.OpensScope():
-        current = current.matching_bracket
+        if ((current.value == '{' or
+             (current.is_pseudo_paren and current.next_token.value == '{')) and
+            format_token.Subtype.DICTIONARY_VALUE in current.subtypes):
+          # A dictionary entry that cannot fit on a single line shouldn't matter
+          # to this calcuation. If it can't fit on a single line, then the
+          # opening should be on the same line as the key and the rest on
+          # newlines after it. But the other entries should be on single lines
+          # if possible.
+          while current:
+            if current == closing:
+              return True
+            if format_token.Subtype.DICTIONARY_KEY in current.subtypes:
+              break
+            current = current.next_token
+        else:
+          current = current.matching_bracket
       else:
         current = current.next_token
+
+    # At this point, current is the closing bracket. Go back one to get the the
+    # end of the dictionary entry.
+    current = current.previous_token
     length = current.total_length - entry_start.total_length
     length += len(entry_start.value)
-    return length + self.stack[-2].indent + 2 < self.column_limit
+    return length + self.stack[-2].indent <= self.column_limit
 
 
 def _IsFunctionCallWithArguments(token):
