@@ -72,8 +72,8 @@ class UnwrappedLine(object):
           _SpaceRequiredBetween(prev_token, token)):
         token.spaces_required_before = 1
 
-      token.total_length = (
-          prev_length + len(token.value) + token.spaces_required_before)
+      tok_len = len(token.value) if not token.is_pseudo_paren else 0
+      token.total_length = prev_length + tok_len + token.spaces_required_before
 
       # The split penalty has to be computed before {must|can}_break_before,
       # because these may use it for their decision.
@@ -143,8 +143,8 @@ class UnwrappedLine(object):
     return self.AsCode()
 
   def __repr__(self):  # pragma: no cover
-    tokens_repr = ','.join(['{0}({1!r})'.format(tok.name, tok.value)
-                            for tok in self._tokens])
+    tokens_repr = ','.join(
+        ['{0}({1!r})'.format(tok.name, tok.value) for tok in self._tokens])
     return 'UnwrappedLine(depth={0}, tokens=[{1}])'.format(self.depth,
                                                            tokens_repr)
 
@@ -194,7 +194,10 @@ def _SpaceRequiredBetween(left, right):
     # Space between keyword... tokens and pseudo parens.
     return True
   if left.is_pseudo_paren or right.is_pseudo_paren:
-    # The pseudo-parens shouldn't affect spacing.
+    # There should be a space after the ':' in a dictionary.
+    if left.OpensScope():
+      return True
+    # The closing pseudo-paren shouldn't affect spacing.
     return False
   if left.is_continuation or right.is_continuation:
     # The continuation node's value has all of the spaces it needs.
